changeset 27420:3da583097fca

bundle: clarify help text The file might not be compressed; the interactions between -a, --base, and a named or default repository weren't clear.
author timeless <timeless@mozdev.org>
date Thu, 17 Dec 2015 14:58:52 +0000
parents 7e2495bf0ad8
children 930f529b0d5f
files mercurial/commands.py
diffstat 1 files changed, 8 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/mercurial/commands.py	Sun Dec 13 20:07:19 2015 +0900
+++ b/mercurial/commands.py	Thu Dec 17 14:58:52 2015 +0000
@@ -1300,13 +1300,14 @@
 def bundle(ui, repo, fname, dest=None, **opts):
     """create a changegroup file
 
-    Generate a compressed changegroup file collecting changesets not
-    known to be in another repository.
-
-    If you omit the destination repository, then hg assumes the
-    destination will have all the nodes you specify with --base
-    parameters. To create a bundle containing all changesets, use
-    -a/--all (or --base null).
+    Generate a changegroup file collecting changesets to be added
+    to a repository.
+
+    To create a bundle containing all changesets, use -a/--all
+    (or --base null). Otherwise, hg assumes the destination will have
+    all the nodes you specify with --base parameters. Otherwise, hg
+    will assume the repository has all the nodes in destination, or
+    default-push/default if no destination is specified.
 
     You can change bundle format with the -t/--type option. You can
     specify a compression, a bundle version or both using a dash